==> ejc-jltest-api-3.0.0-20240309.075006-30-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangercDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定C清单
 * 
 * @author generator
 * 
 */
public class DangercDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Long detailType; // 类别
    private String detailLink; // 管理环节
    private String detailContent; // 隐患内容
    private String detailResult; // 判定结果
    private String detailMemo; // 备注
    private String detailCondition; // 自查情况
    

    public Long getDangerId() {
        return dangerId;
    }

    public void setDangerId(Long dangerId) {
        this.dangerId = dangerId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public Long getDetailType() {
        return detailType;
    }

    public void setDetailType(Long detailType) {
        this.detailType = detailType;
    }
    public String getDetailLink() {
        return detailLink;
    }

    public void setDetailLink(String detailLink) {
        this.detailLink = detailLink;
    }
    public String getDetailContent() {
        return detailContent;
    }

    public void setDetailContent(String detailContent) {
        this.detailContent = detailContent;
    }
    public String getDetailResult() {
        return detailResult;
    }

    public void setDetailResult(String detailResult) {
        this.detailResult = detailResult;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getDetailCondition() {
        return detailCondition;
    }

    public void setDetailCondition(String detailCondition) {
        this.detailCondition = detailCondition;
    }
    
}

==> ejc-jltest-api-3.0.0-20251024.061248-161-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangercDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 重大事故隐患判定C清单
 *
 * @author generator
 */
public class DangercDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long dangerId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Long detailType; // 类别
    private String detailLink; // 管理环节
    private String detailContent; // 隐患内容
    private String detailResult; // 判定结果
    private String detailMemo; // 备注
    private String detailCondition; // 自查情况


    public Long getDangerId() {
        return dangerId;
    }

    public void setDangerId(Long dangerId) {
        this.dangerId = dangerId;
    }

    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getDetailType() {
        return detailType;
    }
    @ReferDeserialTransfer
    public void setDetailType(Long detailType) {
        this.detailType = detailType;
    }

    public String getDetailLink() {
        return detailLink;
    }

    public void setDetailLink(String detailLink) {
        this.detailLink = detailLink;
    }

    public String getDetailContent() {
        return detailContent;
    }

    public void setDetailContent(String detailContent) {
        this.detailContent = detailContent;
    }

    public String getDetailResult() {
        return detailResult;
    }

    public void setDetailResult(String detailResult) {
        this.detailResult = detailResult;
    }

    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

    public String getDetailCondition() {
        return detailCondition;
    }

    public void setDetailCondition(String detailCondition) {
        this.detailCondition = detailCondition;
    }

}
